@@ -39,7 +39,8 @@ from consolekit.utils import abort
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import DelimitedList
 from domdf_python_tools.typing import PathLike
-from dulwich.errors import NotGitRepository  # type: ignore
+from dulwich.errors import NotGitRepository
+from dulwich.porcelain import fetch
 from github import Github, GithubException
 from github.AuthenticatedUser import AuthenticatedUser
 from github.Repository import Repository
@@ -55,7 +56,7 @@ from repo_helper_github.options import token_option, version_callback
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.1.0"
+__version__: str = "0.1.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = [
@@ -166,13 +167,16 @@ class GithubManager(RepoHelper):
 			click.echo(f"Success! View the repository online at {repo.html_url}")
 
 			try:
-				# Try to set the upstream url, or fail silently
-				config = Repo('.').get_config()
-				config.set(("remote", "origin"), "url", repo.ssh_url.encode("UTF-8"))
-				config.write_to_path()
-
+				dulwich_repo = Repo('.')
 			except NotGitRepository:
-				pass
+				return 0
+
+			config = dulwich_repo.get_config()
+			config.set(("remote", "origin"), "url", repo.ssh_url.encode("UTF-8"))
+			config.set(("remote", "origin"), "fetch", b"+refs/heads/*:refs/remotes/origin/*")
+			config.write_to_path()
+
+			fetch(dulwich_repo, remote_location="origin")
 
 		return 0
 
